Timeline

Struct Timeline 

pub struct Timeline {
    anims: Vec<Box<dyn CoreItemAnimation>>,
    cur_sec: f64,
    planning_static_start_sec: Option<f64>,
}
A timeline for a animations.

Fields

anims: Vec<Box<dyn CoreItemAnimation>>cur_sec: f64planning_static_start_sec: Option<f64>

The start time of the planning static anim. When it is some, it means that it is showing and has a planning static anim.

Implementations

Source

impl Timeline

pub fn new() -> Self

Create a new timeline.

pub fn show(&mut self) -> &mut Self

Show the item.

This will start planning an static anim if there isn’t an planning static anim.

pub fn hide(&mut self) -> &mut Self

Hide the item.

This will submit a static anim if there is an planning static anim.

pub fn forward(&mut self, secs: f64) -> &mut Self

Forward the timeline by secs

pub fn forward_to(&mut self, target_sec: f64) -> &mut Self

Forward the timeline to target_sec if the current sec is smaller than it.

fn _submit_planning_static_anim(&mut self) -> bool

pub fn play<T: AnyExtractCoreItem>( &mut self, anim: AnimationCell<T>, ) -> &mut Self

Plays an anim.

pub fn eval_at_alpha(&self, alpha: f64) -> Option<(usize, DynItem)>

Evaluate the state at alpha

pub fn eval_at_sec(&self, target_sec: f64) -> Option<(usize, DynItem)>

Evaluate the state at target_sec