pub struct Timeline {
anims: Vec<Box<dyn CoreItemAnimation>>,
cur_sec: f64,
planning_static_start_sec: Option<f64>,
}Expand description
A timeline for a animations.
Fields
anims: Vec<Box<dyn CoreItemAnimation>>cur_sec: f64planning_static_start_sec: Option<f64>The start time of the planning static anim. When it is some, it means that it is showing and has a planning static anim.
Implementations
Sourceimpl Timeline
impl Timeline
Sourcepub fn show(&mut self) -> &mut Self
pub fn show(&mut self) -> &mut Self
Show the item.
This will start planning an static anim if there isn’t an planning static anim.
Sourcepub fn hide(&mut self) -> &mut Self
pub fn hide(&mut self) -> &mut Self
Hide the item.
This will submit a static anim if there is an planning static anim.
Sourcepub fn forward_to(&mut self, target_sec: f64) -> &mut Self
pub fn forward_to(&mut self, target_sec: f64) -> &mut Self
Forward the timeline to target_sec if the current sec is smaller than it.
fn _submit_planning_static_anim(&mut self) -> bool
Sourcepub fn play<T: AnyExtractCoreItem>(
&mut self,
anim: AnimationCell<T>,
) -> &mut Self
pub fn play<T: AnyExtractCoreItem>( &mut self, anim: AnimationCell<T>, ) -> &mut Self
Plays an anim.